pyscard: smartcard library for python
=====================================

[pyscard](https://pyscard.sourceforge.io/) - python smart card library - is a python module adding smart
cards support to [python](https://www.python.org/).

![alt text](https://pyscard.sourceforge.io/_images/pyscard.jpg "pyscard architecture")

Documentation
-------------
https://pyscard.sourceforge.io/user-guide.html#pyscard-user-guide

Installation
------------

Use `python3 -m pip install pyscard`

See [INSTALL.md](INSTALL.md) for more details.

Samples
-------
High level API samples: See https://pyscard.sourceforge.io/pyscard-framework.html#framework-samples
Low level API samples: See https://pyscard.sourceforge.io/pyscard-wrapper.html#wrapper-samples

Continuous Integration status
-----------------------------
Coveralls: [![Coverage Status](https://coveralls.io/repos/LudovicRousseau/pyscard/badge.svg?branch=master&service=github)](https://coveralls.io/github/LudovicRousseau/pyscard?branch=master)

